#
# spec file for package discount
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with fenced_code
%define soname 2

Name:           discount
Version:        2.1.8a
Release:        4.4
Summary:        Markdown text to HTML converter
License:        BSD-3-Clause
Group:          Productivity/Text/Convertors
Url:            http://www.pell.portland.or.us/~orc/Code/discount/
Source:         http://www.pell.portland.or.us/~orc/Code/discount/discount-%{version}.tar.bz2
Patch1:         discount-disable_ldconfig.patch
Patch2:         discount-fix-compile-warings.diff
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  libtool
BuildRequires:  make
Requires:       libmarkdown%{soname} = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Discount is an implementation of John Gruber’s Markdown text to HTML language
with some extensions from PHP Markdown Extra, Pandoc, and other implementations
of Markdown.

%package -n libmarkdown%{soname}
Summary:        Markdown text to HTML converter library
Group:          Development/Libraries/C and C++

%description -n libmarkdown%{soname}
Discount is an implementation of John Gruber’s Markdown text to HTML language
with some extensions from PHP Markdown Extra, Pandoc, and other implementations
of Markdown.

%package -n libmarkdown-devel
Summary:        Markdown text to HTML converter library
Group:          Development/Libraries/C and C++
Requires:       libmarkdown%{soname} = %{version}

%description -n libmarkdown-devel
Discount is an implementation of John Gruber’s Markdown text to HTML language
with some extensions from PHP Markdown Extra, Pandoc, and other implementations
of Markdown.

%prep
%setup -q
%patch1
%patch2 -p1

%build
CC="gcc" \
CFLAGS="%{optflags}" \
./configure.sh \
    --shared \
    --prefix="%{_prefix}" \
    --execdir="%{_bindir}" \
    --confdir="%{_sysconfdir}" \
    --libdir="%{_libdir}" \
    --mandir="%{_mandir}" \
%if %{with fenced_code}
    --with-fenced-code \
%endif
    --with-dl=BOTH \
    --enable-all-features

make %{?_smp_mflags}

%install
install -d "%{buildroot}%{_bindir}"
install -d "%{buildroot}%{_mandir}"
install -d "%{buildroot}%{_libdir}"
install -d "%{buildroot}%{_includedir}"

make \
    DESTDIR=%{buildroot} \
    install.everything

%fdupes %{buildroot}%{_mandir}/man3

# update-alternatives
mv %{buildroot}%{_bindir}/markdown %{buildroot}%{_bindir}/discount-markdown
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/markdown
ln -sf %{_sysconfdir}/alternatives/markdown %{buildroot}%{_bindir}/markdown

%post
update-alternatives \
	--install %{_bindir}/markdown markdown %{_bindir}/discount-markdown 20

%postun
if [ $1 -eq 0 ] ; then
	update-alternatives --remove markdown %{_bindir}/discount-markdown
fi

%post   -n libmarkdown%{soname} -p /sbin/ldconfig
%postun -n libmarkdown%{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYRIGHT CREDITS README
%{_bindir}/makepage
%{_bindir}/markdown
%{_bindir}/discount-markdown
%ghost %{_sysconfdir}/alternatives/markdown
%{_bindir}/mkd2html
%{_bindir}/theme
%{_mandir}/man1/*.1%{ext_man}
%{_mandir}/man7/markdown.7%{ext_man}
%{_mandir}/man7/mkd-extensions.7%{ext_man}

%files -n libmarkdown%{soname}
%defattr(-,root,root)
%{_libdir}/libmarkdown.so.%{soname}
%{_libdir}/libmarkdown.so.%{soname}.*

%files -n libmarkdown-devel
%defattr(-,root,root)
%{_includedir}/mkdio.h
%{_libdir}/libmarkdown.so
%{_mandir}/man3/*.3%{ext_man}

%changelog
* Thu May 21 2015 mailaender@opensuse.org
- add symlink with update-alternatives to un-conflict Markdown.pl
* Thu Apr 30 2015 mardnh@gmx.de
- add build condition "fenced_code" to conditionally run configure
  with "--with-fenced-code"
  Building with this condition enables PHP markdown extra-style fenced code
  sections, where your chunks of code are surrounded by ~~~ lines instead
  of being indented 4 spaces.
* Thu Apr 30 2015 mardnh@gmx.de
- update to 2.1.8a
- correct license in spec file. It's actually BSD-3-Clause
- added patch for fixing some comiler warnings:
  discount-fix-compile-warings.diff
- ran spec-cleaner and specfile cleanup
- change from version 2.1.8a
  When I put in the patch to ...
  * Change the mail demangler to a debian-specific ‘always mangle one way’ hack.
    (enabled with the configure.sh option –debian-glitch)
  I messed up the format string and made the mangled email address into a fixed
  bogus string. Sigh. Fixed (thanks to a patch from Alessandro Ghedini), updated
  (and I really have to expand the runtime configuration flags array to be long
  enough to fit 64 settings, but that’s a fix for a different day) and released.
- change from version 2.1.8
  After a year or so of letting the code sit and slowly accumulate fixes, a new
  version which fixes a wad of bugs and adds a few new features. Some of this
  code is front other people, and those changes will be marked with their names:
  * FINALLY address the bug where markdown extra-style footnotes lose numbering
    when they show up in nested element; I was not carrying the m-e reference#
    inside the footnotes structure, but was instead carrying it in the parent
    structure and not updating it. So I changed the footnotes structure to
    include the reference + the list of footnotes, which made the misnumbering
    go away on my tests.
  * Fix makefile distclean to cleanup all the generated files and corrected the
    names of the installed sample program man pages to end in .1
    (Mark Pizzolato mark@infocomm.com)
  * Change the mail demangler to a debian-specific ‘always mangle one way’ hack.
    (enabled with the configure.sh option –debian-glitch)
  * Add –with-unmangled-email compile-time flag to disable mailto: mangling
  * Allow the magic output filename -, which means send output to stdout instead
    of to a file.
  * Fix a bug where autolink + github flavored markdown absorbs the ^C eoln
    character into a link at the end of a line.
  * Tweak install.samples so that the user can supply a SAMPLE_PFX on the
    command line SAMPLE_PFX=discount- make install.samples to install the sample
    programs with a package-specific prefix.
  * Emit pages in utf-8 instead of us-ascii (simply a change to the
    Content-Type meta) (Nathan Phillip Brink binki@gentoo.org)
  * Patch the horrible list handler to support long numeric list items
    (George Hartzell hartzell@alerce.com)
  * Various bugfixes (Masayoshi Sekimura sekimura@gmail.com)
  * Fix support for CFLAGS=-m32 ./configure.sh by using CFLAGS for all build
    invokations of CC. (Nathan Phillip Brink binki@gentoo.org)
  * Github-style language attributes on fenced code blocks
    (Loren Segal lsegal@amazon.com)
  * When defining WORD & DWORD, check first for the MS Windows WinDef.h file;
    if found, include it instead of defining WORD & DWORD ourselves.
  * support url-encoded anchor links with –with-urlencoded-anchor option
    (Daisuke Murase typester@cpan.org)
- change from version 2.1.6
  does nothing except for some bugfixes (and ignores some particularly scary
  ones that I /must/ fix soon) and adds two small features.
  * A < at the end of the input is exactly the same as \<(space)
  * Markdown.pl does not appear to escape \<[nonwhite] sequences. Sigh.
  * Tweak the previous Markdown does not escape... commit to simply push out
    the backslash and back up to the start of the <[nonwhite] sequence,
    so -fnohtml will continue to work.
  * Treat hard <br/> (via two spaces) as whitespace.
  * Tweak divquote handling so that two adjacent divquotes won’t die if there
    is a space between the second > & leading %%
  * Tweak one of the list tests back to the previous behavior (I’ve put in a
    hack for list indentation, and accidentally committed the changes. Oops!)
  The features are that I now use styles for table cell alignment instead of
  align=, and that I’m using the 3-clause BSD license for this release
  (because there is one widely used closed-source license that claims that you
  can’t dynamically link with code that uses the 4-clause license. Fine.
  I’ll 3-clause this release to make the stupid GPL happy.)
* Tue Dec 18 2012 lnussel@suse.de
- correct license in spec file. It's actually BSD4c
- changes from version 2.1.5a:
  * MKD_NOSTYLE – treat <style> blocks as regular html.
  * github flavored markdown support
  * in the markdown program, add
  - S flag (tell markdown to spit out style sections)
  - n flag (tell markdown not to output generated text)
- version 2.1.1.1 implements PHP markdown extra-style fenced code sections,
  where your chunks of code are surrounded by ~~~ lines instead of being
  indented 4 spaces.
- changes from version 2.1.0:
  * makepage now accepts markdown option flags a'la the markdown program (via
  - Fxxxx, -fname, or in the MARKDOWN_FLAGS environment variable.)
  * add a -E flag to theme to ignore context-sensitivity on <?theme xxx?> substitutions.
* Wed May  4 2011 pascal.bleser@opensuse.org
- update to 2.0.9: no user-visible changes
- changes from 2.0.8:
  * changes and optimizations were made in table handling
  * a collection of bug and documentation fixes were made
- changes from 2.0.7:
  * the PHP markdown-extra style footnotes were documented
  * a new public function was added to modify the output that is generated for
    them
  * a few small typographical corrections were made to other manpages
- changes from 2.0.6:
  * support was added for PHP markdown extra footnotes
- changes from 2.0.5:
  * small tweaks to the table-of-contents generator
  * a change to the arguments of linkyformat() for inside-tag formatting
  * adds an expanded definition of CSS class names to include dashes and
    underscores
* Sat Jan 15 2011 pascal.bleser@opensuse.org
- initial version (2.0.4)
